package com.isu.gaswellwatch.controller;

import java.util.Collection;
import java.util.List;

import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.isu.gaswellwatch.service.GasWellService;
import com.isu.gaswellwatch.entity.Response;
import com.isu.gaswellwatch.enums.LogType;
import com.isu.gaswellwatch.dto.GasWellCreateRequest;
import com.isu.gaswellwatch.dto.GasWellEditRequest;
import com.isu.gaswellwatch.vo.GasWellPageQuery;
import com.isu.gaswellwatch.vo.GasWellVO;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.isu.gaswellwatch.annotation.OperationLog;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

/**
 * 气井管理
 *
 * @author scwsl
 * @date 2024-11-17
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/gaswell")
public class GasWellController {

    private final GasWellService gasWellService;

    /**
     * 查询气井列表
     */
    @GetMapping
    public Response<Page<GasWellVO>> page(GasWellPageQuery query) {
        return Response.succeed(gasWellService.pageForQuery(query));
    }

    /**
     * 获取气井详细信息
     */
    @GetMapping(value = "/{id}")
    public Response<GasWellVO> getInfo(@PathVariable("id") Long id) {
        return Response.succeed(gasWellService.selectGasWellById(id));
    }

    /**
     * 新增气井
     */
    @PostMapping
    @OperationLog(description = "新增气井", type = LogType.ADD)
    public Response<String> add(@RequestBody @Valid GasWellCreateRequest gasWellCreateRequest) {
            gasWellService.insertGasWell(gasWellCreateRequest);
        return Response.succeed();
    }

    /**
     * 修改气井
     */
    @PutMapping
    @OperationLog(description = "修改气井", type = LogType.UPDATE)
    public Response<String> edit(@RequestBody GasWellEditRequest gasWellEditRequest) {
            gasWellService.updateGasWell(gasWellEditRequest);
        return Response.succeed();
    }

    /**
     * 删除气井
     */
    @DeleteMapping("/{ids}")
    @OperationLog(description = "删除气井", type = LogType.DELETE)
    public Response<String> delete(@PathVariable Collection<Long> ids) {
            gasWellService.deleteGasWellByIds(ids);
        return Response.succeed();
    }

}
