package com.isu.gaswellwatch.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.isu.gaswellwatch.annotation.OperationLog;
import com.isu.gaswellwatch.dto.LoginDTO;
import com.isu.gaswellwatch.dto.ModifyPasswordDTO;
import com.isu.gaswellwatch.dto.UserDTO;
import com.isu.gaswellwatch.dto.UserEditDTO;
import com.isu.gaswellwatch.entity.Response;
import com.isu.gaswellwatch.entity.User;
import com.isu.gaswellwatch.enums.LogType;
import com.isu.gaswellwatch.service.UserService;
import com.isu.gaswellwatch.vo.MenuTreeVO;
import com.isu.gaswellwatch.vo.UserLoginInfoVO;
import com.isu.gaswellwatch.vo.UserVO;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("user")
public class UserController {
    /**
     * 服务对象
     */
    @Resource
    private UserService userService;

    @PostMapping("/doLogin")
    @OperationLog(description = "用户登录",type = LogType.LOGIN)
    public Response<UserLoginInfoVO> doLogin(@RequestBody @Valid LoginDTO loginDTO){
        return Response.succeed(userService.doLogin(loginDTO));
    }

    @GetMapping("/getMenuTreeByToken")
    public Response<List<MenuTreeVO>> getMenuTreeByToken(){
        return Response.succeed(userService.getMenuTreeByToken());
    }


    @GetMapping("/logout")
    @OperationLog(description = "用户注销",type = LogType.LOGOUT)
    public Response<String> logout(){
        userService.logout();
        return Response.succeed();
    }

    @GetMapping("/getUser")
    public Response<UserVO> getUser(@RequestParam Long id){
        return Response.succeed(userService.getUser(id));
    }

    @PostMapping("/modifyPassword")
    public Response<String> modifyPassword(@RequestBody @Valid ModifyPasswordDTO modifyPasswordDTO){
        userService.modifyPassword(modifyPasswordDTO);
        return Response.succeed();
    }


    @GetMapping("/page")
    public Response<Page<UserVO>> page(@RequestParam(defaultValue = "1") Integer currentPage ,
                                       @RequestParam(defaultValue = "10") Integer pageSize,
                                       @RequestParam(required = false) String username,
                                       @RequestParam(required = false) String name,
                                       @RequestParam(required = false) Long roleId,
                                       @RequestParam(required = false) String isEnable){
        return Response.succeed(userService.page(currentPage,pageSize,username,name,roleId,isEnable));
    }

    @PostMapping("/add")
    @OperationLog(description = "新增用户",type = LogType.ADD)
    public Response<String> add(@RequestBody @Valid UserDTO userDTO){
        userService.add(userDTO);
        return Response.succeed();
    }

    @GetMapping("/setEnable")
    public Response<String> setEnable(@RequestParam Long userId, @RequestParam String isEnable){
        userService.setEnable(userId,isEnable);
        return Response.succeed();
    }

    @PostMapping("/edit")
    @OperationLog(description = "编辑用户",type = LogType.UPDATE)
    public Response<String> edit(@RequestBody @Valid UserEditDTO userEditDTO){
        userService.edit(userEditDTO);
        return Response.succeed();
    }

    @GetMapping("/delete")
    @OperationLog(description = "删除用户",type = LogType.DELETE)
    public Response<String> delete(@RequestParam Long id){
        userService.delete(id);
        return Response.succeed();
    }
    @OperationLog(description = "重置密码",type = LogType.UPDATE)
    @GetMapping("/reset")
    public Response<String> reset(@RequestParam Long id){
        userService.reset(id);
        return Response.succeed("重置密码成功，重置为123456");
    }

    @GetMapping("/export")
    public void export(HttpServletResponse response,
                       @RequestParam(required = false) String username,
                       @RequestParam(required = false) String name,
                       @RequestParam(required = false) Long roleId,
                       @RequestParam(required = false) String isEnable) {
        userService.export(response,username, name, roleId,isEnable);

    }




}
