package com.isu.gaswellwatch.modbus.data.decode.listener;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.amqp.core.BatchMessageListener;
import org.springframework.amqp.core.Message;

import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.List;

/**
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2024/11/23 0:47
 */
@Slf4j
public class ModbusMessageBackupListener implements BatchMessageListener {

    @Override
    public void onMessage(Message message) {
        this.onMessageBatch(List.of(message));
    }

    @Override
    public void onMessageBatch(List<Message> messages) {
        Path filePath;
        String messageString, queueName, backupFileName;
        for (Message message : messages) {
            queueName = message.getMessageProperties().getConsumerQueue();
            backupFileName = StringUtils.replace(queueName, "/", "_");
            messageString = new String(message.getBody());
            filePath = Paths.get("D:\\modbus\\data\\" + backupFileName + ".data");
            try (BufferedWriter writer = Files.newBufferedWriter(filePath, StandardCharsets.UTF_8, StandardOpenOption.APPEND)) {
                writer.write(messageString);
                writer.write("\n");
            } catch (IOException e) {
                log.error("Backup message failed. QueueName {}, Message {}", queueName, messageString, e);
            }
        }
    }

}
